@@ -1,6 +1,5 @@
 import aiohttp
 
-from typing import Tuple, Dict
 from fastapi import Response
 
 
@@ -13,6 +12,3 @@ async def proxy_response(response: aiohttp.ClientResponse) -> Response:
         media_type="application/json",
     )
 
-
-def tuple_to_dict(tup: Tuple[str, str]) -> Dict[str, str]:
-    return dict([tup])
